@@ -39,7 +39,7 @@ from six.moves import html_entities
 from update_checker import update_check
 from warnings import simplefilter, warn_explicit
 
-__version__ = '2.0.12'
+__version__ = '2.0.13'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -66,6 +66,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'approve':             'api/approve/',
                  'authorize':           'api/v1/authorize/',
                  'banned':              'r/%s/about/banned/',
+                 'by_id':               'by_id/',
                  'captcha':             'captcha/',
                  'clearflairtemplates': 'api/clearflairtemplates/',
                  'comment':             'api/comment/',
@@ -138,7 +139,12 @@ class Config(object):  # pylint: disable-msg=R0903
                  'user':                'user/%s/',
                  'user_about':          'user/%s/about/',
                  'username_available':  'api/username_available/',
-                 'vote':                'api/vote/'}
+                 'vote':                'api/vote/',
+                 'wiki_edit':           'api/wiki/edit/',
+                 'wiki_page':           'r/%s/wiki/%s',  # No trailing /
+                 'wiki_pages':          'r/%s/wiki/pages/',
+                 'wiki_banned':         'r/%s/about/wikibanned/',
+                 'wiki_contributors':   'r/%s/about/wikicontributors/'}
     SSL_PATHS = ('access_token_url', 'authorize', 'login')
 
     def __init__(self, site_name):
@@ -167,6 +173,8 @@ class Config(object):  # pylint: disable-msg=R0903
                         obj['subreddit_kind']:  objects.Subreddit,
                         'modaction':            objects.ModAction,
                         'more':                 objects.MoreComments,
+                        'wikipage':             objects.WikiPage,
+                        'wikipagelisting':      objects.WikiPageListing,
                         'UserList':             objects.UserList}
         self.by_object = dict((value, key) for (key, value) in
                               six.iteritems(self.by_kind))
@@ -388,7 +396,7 @@ class BaseReddit(object):
         :param url: the url to grab content from.
         :param params: a dictionary containing the GET data to put in the url
         :param data: a dictionary containing the extra data to submit
-        :param as_objects: if true return reddit objects else raw json dict.
+        :param as_objects: if True return reddit objects else raw json dict.
         :returns: JSON processed page
 
         """
@@ -398,7 +406,9 @@ class BaseReddit(object):
             hook = self._json_reddit_objecter
         else:
             hook = None
+        self._request_url = url  # Availabile for objecter to use
         data = json.loads(response, object_hook=hook)
+        delattr(self, '_request_url')
         # Update the modhash
         if isinstance(data, dict) and 'data' in data \
                 and 'modhash' in data['data']:
@@ -657,6 +667,24 @@ class UnauthenticatedReddit(BaseReddit):
                                            comment_limit=comment_limit,
                                            comment_sort=comment_sort)
 
+    def get_submissions(self, fullnames, *args, **kwargs):
+        """Yield Submission objects for each fullname provided in `fullnames`.
+
+        A submission fullname looks like `t3_<base36_id>`. Submissions are
+        yielded in the same order they appear in fullnames.
+
+        Up to 100 items are batched at a time, however, this happens
+        transparently.
+
+        """
+        fullnames = fullnames[:]
+        while fullnames:
+            cur = fullnames[:100]
+            fullnames[:100] = []
+            url = self.config['by_id'] + ','.join(cur)
+            for item in self.get_content(url, limit=len(cur), *args, **kwargs):
+                yield item
+
     def get_subreddit(self, subreddit_name, *args, **kwargs):
         """Return a Subreddit object for the subreddit_name specified."""
         if subreddit_name.lower() == 'random':
@@ -668,6 +696,16 @@ class UnauthenticatedReddit(BaseReddit):
         """Return top page."""
         return self.get_content(self.config['top'], *args, **kwargs)
 
+    def get_wiki_page(self, subreddit, page):
+        """Return a WikiPage object for the subreddit and page provided."""
+        return self.request_json(self.config['wiki_page'] %
+                                 (six.text_type(subreddit), page))
+
+    def get_wiki_pages(self, subreddit):
+        """Return a list of WikiPage objects for the subreddit."""
+        return self.request_json(self.config['wiki_pages'] %
+                                 six.text_type(subreddit))
+
     def is_username_available(self, username):
         """Return True if username is valid and available, otherwise False."""
         params = {'user': username}
@@ -787,16 +825,24 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         helpers._request.empty()  # pylint: disable-msg=W0212
         self.user = None
 
+    def edit_wiki_page(self, subreddit, page, content, reason=''):
+        """Create or edit a wiki page with title `page` for `subreddit`."""
+        data = {'content': content,
+                'page': page,
+                'r':  six.text_type(subreddit),
+                'reason': reason}
+        return self.request_json(self.config['wiki_edit'], data=data)
+
     def get_access_information(self, code,  # pylint: disable-msg=W0221
                                update_session=True):
         """Return the access information for an OAuth2 authorization grant.
 
         :param code: the code received in the request from the OAuth2 server
         :param update_session: Update the current session with the retrieved
-        token(s).
+            token(s).
         :returns: A dictionary with the key/value pairs for access_token,
-        refresh_token and scope. The refresh_token value will be done when
-        the OAuth2 grant is not refreshable.
+            refresh_token and scope. The refresh_token value will be done when
+            the OAuth2 grant is not refreshable.
 
         """
         retval = super(AuthenticatedReddit, self).get_access_information(code)
@@ -1096,7 +1142,7 @@ class ModConfigMixin(AuthenticatedReddit):
 
 class ModFlairMixin(AuthenticatedReddit):
 
-    """Adds methods requring the 'modflair' scope (or mod access)."""
+    """Adds methods requiring the 'modflair' scope (or mod access)."""
 
     @decorators.restrict_access(scope='modflair')
     def add_flair_template(self, subreddit, text='', css_class='',
@@ -1234,7 +1280,7 @@ class ModFlairMixin(AuthenticatedReddit):
 
 class ModLogMixin(AuthenticatedReddit):
 
-    """Adds methods requring the 'modlog' scope (or mod access)."""
+    """Adds methods requiring the 'modlog' scope (or mod access)."""
 
     @decorators.restrict_access(scope='modlog')
     def get_mod_log(self, subreddit, limit=0, mod=None, action=None, *args,
@@ -1258,7 +1304,7 @@ class ModLogMixin(AuthenticatedReddit):
 
 class ModOnlyMixin(AuthenticatedReddit):
 
-    """Adds methods requring the logged in moderator access."""
+    """Adds methods requiring the logged in moderator access."""
 
     @decorators.restrict_access(scope=None, mod=True)
     def get_banned(self, subreddit):
@@ -1305,6 +1351,18 @@ class ModOnlyMixin(AuthenticatedReddit):
                                 six.text_type(subreddit), limit=limit, *args,
                                 **kwargs)
 
+    @decorators.restrict_access(scope=None, mod=True)
+    def get_wiki_banned(self, subreddit):
+        """Return a list of users banned from the wiki."""
+        return self.request_json(self.config['wiki_banned'] %
+                                 six.text_type(subreddit))
+
+    @decorators.restrict_access(scope=None, mod=True)
+    def get_wiki_contributors(self, subreddit):
+        """Return a list of users who can contribute to the wiki."""
+        return self.request_json(self.config['wiki_contributors'] %
+                                 six.text_type(subreddit))
+
 
 class MySubredditsMixin(AuthenticatedReddit):
 
@@ -1331,7 +1389,7 @@ class MySubredditsMixin(AuthenticatedReddit):
 
 class PrivateMessagesMixin(AuthenticatedReddit):
 
-    """Adds methods requring the 'privatemessages' scope (or login)."""
+    """Adds methods requiring the 'privatemessages' scope (or login)."""
 
     @decorators.restrict_access(scope='privatemessages')
     def _mark_as_read(self, thing_ids, unread=False):
@@ -1414,7 +1472,7 @@ class PrivateMessagesMixin(AuthenticatedReddit):
 
 class SubmitMixin(AuthenticatedReddit):
 
-    """Adds methods requring the 'submit' scope (or login)."""
+    """Adds methods requiring the 'submit' scope (or login)."""
 
     @decorators.restrict_access(scope='submit')
     def _add_comment(self, thing_id, text):
@@ -1474,7 +1532,7 @@ class SubmitMixin(AuthenticatedReddit):
 
 class SubscribeMixin(AuthenticatedReddit):
 
-    """Adds methods requring the 'subscribe' scope (or login)."""
+    """Adds methods requiring the 'subscribe' scope (or login)."""
 
     @decorators.restrict_access(scope='subscribe')
     def subscribe(self, subreddit, unsubscribe=False):
