@@ -277,6 +277,15 @@ class BasicTest(unittest.TestCase, BasicHelper):
             subs.add(self.r.get_subreddit('RANDOM').display_name)
         self.assertTrue(len(subs) > 1)
 
+    def test_get_submissions(self):
+        kind = self.r.config.by_object[Submission]
+
+        def fullname(url):
+            return '{0}_{1}'.format(kind, url.rsplit('/', 2)[1])
+        fullnames = [fullname(self.comment_url), fullname(self.link_url)] * 100
+        retreived = [x.fullname for x in self.r.get_submissions(fullnames)]
+        self.assertEqual(fullnames, retreived)
+
     @reddit_only
     def test_get_top(self):
         num = 50
@@ -933,42 +942,64 @@ class ModeratorUserTest(unittest.TestCase, AuthenticatedHelper):
         self.subreddit = self.r.get_subreddit(self.sr)
         self.other = self.r.get_redditor('pyapitestuser3', fetch=True)
 
+    def add_remove(self, add, remove, listing, add_callback=None):
+        def test_add():
+            add(self.other)
+            if add_callback:
+                add_callback()
+            self.assertTrue(self.other in listing())
+
+        def test_remove():
+            remove(self.other)
+            self.assertTrue(self.other not in listing())
+
+        self.disable_cache()
+        if self.other in listing():
+            test_remove()
+            test_add()
+        else:
+            test_add()
+            test_remove()
+
     def test_accept_moderator_invite_fail(self):
         self.r.login('pyapitestuser3', '1111')
         self.assertRaises(errors.InvalidInvite,
                           self.subreddit.accept_moderator_invite)
 
     def test_ban(self):
-        self.subreddit.ban(self.other)
-        self.assertTrue(self.other in self.subreddit.get_banned())
+        self.add_remove(self.subreddit.add_ban, self.subreddit.remove_ban,
+                        self.subreddit.get_banned)
 
-    def test_make_contributor(self):
-        self.subreddit.make_contributor(self.other)
-        self.assertTrue(self.other in self.subreddit.get_contributors())
+    def test_contributors(self):
+        self.add_remove(self.subreddit.add_contributor,
+                        self.subreddit.remove_contributor,
+                        self.subreddit.get_contributors)
 
-    def test_make_moderator(self):
-        self.assertFalse(self.other in self.subreddit.get_moderators())
-        self.subreddit.make_moderator(self.other)
-        self.r.login('pyapitestuser3', '1111')
-        self.subreddit.accept_moderator_invite()
-        self.assertTrue(self.other in self.subreddit.get_moderators())
+    def test_moderator(self):
+        def add_callback():
+            tmp = Reddit(USER_AGENT, disable_update_check=True)
+            tmp.login('pyapitestuser3', '1111')
+            tmp.get_subreddit(self.sr).accept_moderator_invite()
+
+        self.add_remove(self.subreddit.add_moderator,
+                        self.subreddit.remove_moderator,
+                        self.subreddit.get_moderators,
+                        add_callback)
 
     def test_make_moderator_by_name_failure(self):
-        self.assertTrue(self.other in self.subreddit.get_moderators())
+        self.assertTrue(self.r.user in self.subreddit.get_moderators())
         self.assertRaises(errors.AlreadyModerator,
-                          self.subreddit.make_moderator, text_type(self.other))
+                          self.subreddit.add_moderator, text_type(self.r.user))
 
-    def test_remove_contributor(self):
-        self.subreddit.remove_contributor(self.other)
-        self.assertFalse(self.other in self.subreddit.get_contributors())
+    def test_wiki_ban(self):
+        self.add_remove(self.subreddit.add_wiki_ban,
+                        self.subreddit.remove_wiki_ban,
+                        self.subreddit.get_wiki_banned)
 
-    def test_remove_moderator(self):
-        self.subreddit.remove_moderator(self.other)
-        self.assertFalse(self.other in self.subreddit.get_moderators())
-
-    def test_unban(self):
-        self.subreddit.unban(self.other)
-        self.assertFalse(self.other in self.subreddit.get_banned())
+    def test_wiki_contributors(self):
+        self.add_remove(self.subreddit.add_wiki_contributor,
+                        self.subreddit.remove_wiki_contributor,
+                        self.subreddit.get_wiki_contributors)
 
 
 class OAuth2Test(unittest.TestCase, BasicHelper):
@@ -1281,6 +1312,26 @@ class SubmissionEditTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
         self.subreddit = self.r.get_subreddit(self.sr)
 
+    def test_distinguish_and_undistinguish(self):
+        def verify_distinguish(submission):
+            submission.distinguish()
+            submission.refresh()
+            self.assertTrue(submission.distinguished)
+
+        def verify_undistinguish(submission):
+            submission.undistinguish()
+            submission.refresh()
+            self.assertFalse(submission.distinguished)
+
+        self.disable_cache()
+        submission = six_next(self.subreddit.get_top())
+        if submission.distinguished:
+            verify_undistinguish(submission)
+            verify_distinguish(submission)
+        else:
+            verify_distinguish(submission)
+            verify_undistinguish(submission)
+
     def test_edit_link(self):
         found = None
         for item in self.r.user.get_submitted():
@@ -1521,5 +1572,31 @@ class SubredditTest(unittest.TestCase, AuthenticatedHelper):
                 self.fail('Found reddit in my_reddits.')
 
 
+class WikiTests(unittest.TestCase, BasicHelper):
+    def setUp(self):
+        self.configure()
+        self.subreddit = self.r.get_subreddit(self.sr)
+
+    def test_edit_wiki_page(self):
+        self.r.login(self.un, '1111')
+        page = self.subreddit.get_wiki_page('test')
+        content = 'Body: {0}'.format(uuid.uuid4())
+        page.edit(content)
+        self.disable_cache()
+        page = self.subreddit.get_wiki_page('test')
+        self.assertEqual(content, page.content_md)
+
+    def test_get_wiki_page(self):
+        self.assertEqual(
+            'ucsantabarbara:index',
+            text_type(self.r.get_wiki_page('ucsantabarbara', 'index')))
+
+    def test_get_wiki_pages(self):
+        retval = self.subreddit.get_wiki_pages()
+        self.assertTrue(len(retval) > 0)
+        tmp = self.subreddit.get_wiki_page(retval[0].page).content_md
+        self.assertEqual(retval[0].content_md, tmp)
+
+
 if __name__ == '__main__':
     unittest.main()
